.. gmpy2 documentation master file, created by
   sphinx-quickstart on Fri Feb 24 19:56:16 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gmpy2's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   overview
   mpz
   advmpz
   mpq
   mpfr
   mpc
   cython
   conversion
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

